package Classes::Device;
our @ISA = qw(Monitoring::GLPlugin::SNMP);
use strict;

sub classify {
  my $self = shift;
  if (! ($self->opts->hostname || $self->opts->snmpwalk)) {
    $self->add_unknown('either specify a hostname or a snmpwalk file');
  } else {
    $self->check_snmp_and_model();
    if (! $self->check_messages()) {
      if ($self->opts->verbose && $self->opts->verbose) {
        printf "I am a %s\n", $self->{productname};
      }
      if ($self->{productname} =~ /Fujitsu ServerView /) {
        bless $self, 'Classes::Fujitsu::ServerView';
        $self->debug('using Classes::Fujitsu::ServerView');
      } elsif ($self->implements_mib('SERVERVIEW-STATUS-MIB')) {
        bless $self, 'Classes::Fujitsu::ServerView';
        $self->debug('using Classes::Fujitsu::ServerView');
      } elsif ($self->get_snmp_object('SERVERVIEW-STATUS-MIB', 'sieStAgentId', 0)) {
        bless $self, 'Classes::Fujitsu::ServerView';
        $self->debug('using Classes::Fujitsu::ServerView');
      } elsif ($self->implements_mib('FSC-RAID-MIB')) {
        bless $self, 'Classes::Fujitsu::FscRaid';
        $self->debug('using Classes::Fujitsu::ServerView');
      } else {
        if (my $class = $self->discover_suitable_class()) {
          bless $self, $class;
          $self->debug('using '.$class);
        } else {
          bless $self, 'Classes::Generic';
          $self->debug('using Classes::Generic');
        }
      }
    }
  }
  return $self;
}


package Classes::Generic;
our @ISA = qw(Classes::Device);
use strict;

sub init {
  my $self = shift;
  if ($self->mode =~ /something specific/) {
  } else {
    bless $self, 'Monitoring::GLPlugin::SNMP';
    $self->no_such_mode();
  }
}
